﻿/* Copyright © 2010 Will Shelley
 * All Rights Reserved. See the license.txt file for more information. */
using System;
using System.Collections.Generic;
using System.Text;

namespace System.Net.UPnP
{
    /// <summary>
    /// Provides internet protocol addresses and endpoints (address and port combinations) that are significant to UPnP.
    /// </summary>
    public static class Addresses
    {
        #region Properties
        /// <summary>
        /// Gets the <see cref="System.Net.IPEndPoint"/> which is used by UDP multicast packets to advertise services of a device.
        /// </summary>
        public static IPEndPoint DeviceAdvertisement
        {
            get
            {
                return new IPEndPoint(IPAddress.Parse("239.255.255.250"), 1900);
            }
        }
        /// <summary>
        /// Gets the start address for AutoIP link-local address resolution.
        /// </summary>
        public static IPAddress AutoIPStart
        {
            get
            {
                return IPAddress.Parse("169.254.1.0");
            }
        }
        /// <summary>
        /// Gets the end address for AutoIP link-local address resolution.
        /// </summary>
        public static IPAddress AutoIPEnd
        {
            get
            {
                return IPAddress.Parse("169.254.254.255");
            }
        }
        #endregion
    }
}
